# This file auto generated!
# DO NOT EDIT MANUALLY!

version: str = "0.7.1"
__version__: str = "0.7.1"

commit_hash: str = "g0df19d916f82171ed2866a54d0907c2501511078"
version_timestamp: str = "2025-12-06 16:20:37.460808+00:00"

tag: str = "0.7.1"
branch: str = "HEAD"
commit_date: str = "2025-12-06"
commit_count_since_tag: int = 0



from descanso.jsonrpc import (
    EXTRA_JSON_RPC_METHOD,
    EXTRA_JSON_RPC_REQUEST_ID,
    PackJsonRPC,
)
from descanso.request import HttpRequest


def test_empty_body_omit_params() -> None:
    request = HttpRequest(
        extras=[
            (EXTRA_JSON_RPC_REQUEST_ID, "some_id"),
            (EXTRA_JSON_RPC_METHOD, "some_method"),
        ],
        method="POST",
    )
    expected_body = {
        "id": "some_id",
        "method": "some_method",
        "jsonrpc": "2.0",
    }

    transformer = PackJsonRPC()
    result_request = transformer.transform_request(request, [], [], {})

    assert result_request.body == expected_body


def test_body_set_in_params() -> None:
    params = {"param1": "value1", "param2": "value2"}
    request = HttpRequest(
        body=params,
        extras=[
            (EXTRA_JSON_RPC_REQUEST_ID, "some_id"),
            (EXTRA_JSON_RPC_METHOD, "some_method"),
        ],
        method="POST",
    )
    expected_body = {
        "id": "some_id",
        "method": "some_method",
        "jsonrpc": "2.0",
        "params": params,
    }

    transformer = PackJsonRPC()
    result_request = transformer.transform_request(request, [], [], {})

    assert result_request.body == expected_body
